..
    Copyright (C) 2020 Technische Universität Graz.

    invenio-rdm-pure is free software; you can redistribute it and/or
    modify it under the terms of the MIT License; see LICENSE file for more
    details.

Authors
=======

Invenio module for Pure integration

- Technische Universität Graz <info@tugraz.at>
